@@ -1,14 +1,8 @@
-import sys
-
-if sys.version_info < (3, 8):
-    from typing_extensions import TypedDict
-else:
-    from typing import TypedDict
-
-
 from di import BaseContainer
 from starlette.responses import Response
 
+from xpresso._utils.compat import TypedDict
+
 
 class _XpressoASGIExtension(TypedDict):
     container: BaseContainer
