@@ -1,49 +1,26 @@
 import inspect
 import typing
 
-from di import Dependant, Marker
-from di.api.dependencies import CacheKey, DependantBase
+from di import Dependant
+from di.api.dependencies import CacheKey, DependantBase, MarkerBase
 
+from xpresso._utils.compat import Protocol
 from xpresso.binders.api import (
     BodyExtractor,
-    BodyExtractorMarker,
     OpenAPIBody,
-    OpenAPIBodyMarker,
     OpenAPIParameter,
-    OpenAPIParameterMarker,
     ParameterExtractor,
-    ParameterExtractorMarker,
 )
 
+T = typing.TypeVar("T", covariant=True)
 
-class ParameterBinderMarker(Marker):
-    def __init__(
-        self,
-        *,
-        in_: str,
-        extractor_marker: ParameterExtractorMarker,
-        openapi_marker: OpenAPIParameterMarker,
-    ) -> None:
-        super().__init__(call=None, scope="connection")
-        self.in_ = in_
-        self.extractor_marker = extractor_marker
-        self.openapi_marker = openapi_marker
 
-    def register_parameter(self, param: inspect.Parameter) -> DependantBase[typing.Any]:
-        return ParameterBinder(
-            in_=self.in_,
-            openapi=self.openapi_marker.register_parameter(param),
-            extractor=self.extractor_marker.register_parameter(param),
-        )
+class SupportsMarker(Protocol[T]):
+    def register_parameter(self, param: inspect.Parameter) -> T:
+        ...
 
 
 class ParameterBinder(Dependant[typing.Any]):
-    __slots__ = (
-        "in_",
-        "alias",
-        "openapi",
-    )
-
     def __init__(
         self,
         in_: str,
@@ -61,9 +38,27 @@ class ParameterBinder(Dependant[typing.Any]):
         return (self.__class__, self.openapi.name, self.in_)
 
 
-class BodyBinder(Dependant[typing.Any]):
-    __slots__ = ("openapi", "extractor")
+class ParameterBinderMarker(MarkerBase):
+    def __init__(
+        self,
+        *,
+        in_: str,
+        extractor_marker: SupportsMarker[ParameterExtractor],
+        openapi_marker: SupportsMarker[OpenAPIParameter],
+    ) -> None:
+        self.in_ = in_
+        self.extractor_marker = extractor_marker
+        self.openapi_marker = openapi_marker
 
+    def register_parameter(self, param: inspect.Parameter) -> DependantBase[typing.Any]:
+        return ParameterBinder(
+            in_=self.in_,
+            openapi=self.openapi_marker.register_parameter(param),
+            extractor=self.extractor_marker.register_parameter(param),
+        )
+
+
+class BodyBinder(Dependant[typing.Any]):
     def __init__(
         self,
         *,
@@ -74,15 +69,19 @@ class BodyBinder(Dependant[typing.Any]):
         self.openapi = openapi
         self.extractor = extractor
 
+    @property
+    def cache_key(self) -> CacheKey:
+        # Treat each body as unique since there should only be one body
+        return (self.__class__, id(self))
 
-class BodyBinderMarker(Marker):
+
+class BodyBinderMarker(MarkerBase):
     def __init__(
         self,
         *,
-        extractor_marker: BodyExtractorMarker,
-        openapi_marker: OpenAPIBodyMarker,
+        extractor_marker: SupportsMarker[BodyExtractor],
+        openapi_marker: SupportsMarker[OpenAPIBody],
     ) -> None:
-        super().__init__(call=None, scope="connection")
         self.extractor_marker = extractor_marker
         self.openapi_marker = openapi_marker
 
